# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(516, 151)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_main = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_main.setObjectName("verticalLayout_main")
        self.scrollArea = QtWidgets.QScrollArea(self.centralwidget)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 496, 73))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.gif_layout = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.gif_layout.setObjectName("gif_layout")
        self.column0 = QtWidgets.QVBoxLayout()
        self.column0.setObjectName("column0")
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.column0.addItem(spacerItem)
        self.gif_layout.addLayout(self.column0)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_main.addWidget(self.scrollArea)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.beginning_button = QtWidgets.QPushButton(self.centralwidget)
        self.beginning_button.setText("")
        icon = QtGui.QIcon.fromTheme("media-skip-backward")
        self.beginning_button.setIcon(icon)
        self.beginning_button.setObjectName("beginning_button")
        self.horizontalLayout.addWidget(self.beginning_button)
        self.previous_button = QtWidgets.QPushButton(self.centralwidget)
        self.previous_button.setText("")
        icon = QtGui.QIcon.fromTheme("media-seek-backward")
        self.previous_button.setIcon(icon)
        self.previous_button.setObjectName("previous_button")
        self.horizontalLayout.addWidget(self.previous_button)
        self.play_button = QtWidgets.QPushButton(self.centralwidget)
        self.play_button.setText("")
        icon = QtGui.QIcon.fromTheme("media-playback-start")
        self.play_button.setIcon(icon)
        self.play_button.setObjectName("play_button")
        self.horizontalLayout.addWidget(self.play_button)
        self.next_button = QtWidgets.QPushButton(self.centralwidget)
        self.next_button.setText("")
        icon = QtGui.QIcon.fromTheme("media-seek-forward")
        self.next_button.setIcon(icon)
        self.next_button.setObjectName("next_button")
        self.horizontalLayout.addWidget(self.next_button)
        self.end_button = QtWidgets.QPushButton(self.centralwidget)
        self.end_button.setText("")
        icon = QtGui.QIcon.fromTheme("media-skip-forward")
        self.end_button.setIcon(icon)
        self.end_button.setObjectName("end_button")
        self.horizontalLayout.addWidget(self.end_button)
        self.line = QtWidgets.QFrame(self.centralwidget)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout.addWidget(self.line)
        self.zoom_out_button = QtWidgets.QPushButton(self.centralwidget)
        self.zoom_out_button.setText("")
        icon = QtGui.QIcon.fromTheme("zoom-out")
        self.zoom_out_button.setIcon(icon)
        self.zoom_out_button.setObjectName("zoom_out_button")
        self.horizontalLayout.addWidget(self.zoom_out_button)
        self.zoom_box = QtWidgets.QLineEdit(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.zoom_box.sizePolicy().hasHeightForWidth())
        self.zoom_box.setSizePolicy(sizePolicy)
        self.zoom_box.setMinimumSize(QtCore.QSize(33, 26))
        self.zoom_box.setMaximumSize(QtCore.QSize(33, 26))
        self.zoom_box.setObjectName("zoom_box")
        self.horizontalLayout.addWidget(self.zoom_box)
        self.zoom_in_button = QtWidgets.QPushButton(self.centralwidget)
        self.zoom_in_button.setToolTip("")
        self.zoom_in_button.setText("")
        icon = QtGui.QIcon.fromTheme("zoom-in")
        self.zoom_in_button.setIcon(icon)
        self.zoom_in_button.setObjectName("zoom_in_button")
        self.horizontalLayout.addWidget(self.zoom_in_button)
        self.zoom_reset_button = QtWidgets.QPushButton(self.centralwidget)
        self.zoom_reset_button.setText("")
        icon = QtGui.QIcon.fromTheme("zoom-original")
        self.zoom_reset_button.setIcon(icon)
        self.zoom_reset_button.setObjectName("zoom_reset_button")
        self.horizontalLayout.addWidget(self.zoom_reset_button)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.quit_button = QtWidgets.QPushButton(self.centralwidget)
        self.quit_button.setText("")
        icon = QtGui.QIcon.fromTheme("window-close")
        self.quit_button.setIcon(icon)
        self.quit_button.setObjectName("quit_button")
        self.horizontalLayout.addWidget(self.quit_button)
        self.verticalLayout_main.addLayout(self.horizontalLayout)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 516, 22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "multigifview"))
        self.beginning_button.setShortcut(_translate("MainWindow", "B"))
        self.previous_button.setShortcut(_translate("MainWindow", "P"))
        self.play_button.setShortcut(_translate("MainWindow", "Space"))
        self.next_button.setShortcut(_translate("MainWindow", "N"))
        self.end_button.setShortcut(_translate("MainWindow", "E"))
        self.zoom_out_button.setShortcut(_translate("MainWindow", "-"))
        self.zoom_box.setText(_translate("MainWindow", "100"))
        self.zoom_in_button.setShortcut(_translate("MainWindow", "+"))
        self.zoom_reset_button.setShortcut(_translate("MainWindow", "="))
